#
# spec file for package webcamoid
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           webcamoid
Version:        8.7.1
Release:        lp152.2.3
Summary:        Webcam applet for Plasma
License:        GPL-3.0-or-later
Group:          System/GUI/KDE
URL:            https://webcamoid.github.io/
Source:         https://github.com/hipersayanX/Webcamoid/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf5-filesystem
BuildRequires:  libqt5-linguist
BuildRequires:  perl-Text-Markdown
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.9
BuildRequires:  pkgconfig(Qt5OpenGL) >= 5.9
BuildRequires:  pkgconfig(Qt5Qml) >= 5.9
BuildRequires:  pkgconfig(Qt5QuickControls2) >= 5.9
BuildRequires:  pkgconfig(Qt5Svg) >= 5.9
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.9
BuildRequires:  pkgconfig(Qt5Xml) >= 5.9
BuildRequires:  pkgconfig(libavcodec) >= 58.7.100
BuildRequires:  pkgconfig(libavdevice) >= 57.0.0
BuildRequires:  pkgconfig(libavformat) >= 58.0.102
BuildRequires:  pkgconfig(libavutil) >= 56.6.100
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libswscale) >= 5.0.101
BuildRequires:  pkgconfig(libv4l2)
Requires:       libqt5-qtquickcontrols
Requires:       libqt5-qtquickcontrols2
Provides:       plasmoid-webcamoid = %{version}
Obsoletes:      plasmoid-webcamoid < %{version}

%description
Webcam applet for Plasma.

Features:
* Take pictures with the webcam.
* Record videos.
* Manages multiple webcams.
* Play/Stop capture, this saves resources while the applet is not in use.
* Written in C++.
* Qt based software.
* Custom controls for each webcam.
* Popup applet support (you can embed Webcamoid in the panel).
* +50 video effects available.
* Effects with live previews.
* Translated to many languages.
* Stand alone installation mode (use it as a normal program).
* Use custom network and local files as capture devices.
* Capture from desktop.

%package devel
Summary:        Development headers and libraries for Webcamoid
Group:          Development/Libraries/C and C++
Requires:       plasmoid-webcamoid = %{version}

%description devel
Development headers and libraries for Webcamoid.
Avkys library provides a wide range of plugins for audio and
video playing, recording, capture, and processing.

%prep
%setup -q -n webcamoid-%{version}

%build
%qmake5 \
    Webcamoid.pro \
    LIBDIR=%{_libdir} \
    USE3DPARTYLIBS=0 \
    LICENSEDIR=%{_defaultdocdir}/webcamoid \
    INSTALLDEVHEADERS=1 \
    QMAKE_LRELEASE=%{_bindir}/lrelease-qt5 \
    INSTALLQMLDIR=%{_kf5_qmldir}

make %{?_smp_mflags}

# generate help file
Markdown.pl --html4 README.md > README.html

%install
%qmake5_install

%{kf5_post_install}

%fdupes %{buildroot}%{_datadir}

desktop-file-edit %{buildroot}%{_kf5_applicationsdir}/webcamoid.desktop --remove-category=KDE --add-category=Video --add-category=Player

rm -rf %{buildroot}%{_datadir}/licenses/
rm -rf %{buildroot}%{_datadir}/doc/

%post
/sbin/ldconfig
%icon_theme_cache_post
%desktop_database_post

%postun
/sbin/ldconfig
%icon_theme_cache_postun
%desktop_database_postun

%files
%doc AUTHORS ChangeLog README.html THANKS
%license COPYING
%{_bindir}/%{name}
%{_kf5_applicationsdir}/%{name}.desktop
%{_libdir}/libavkys.so.*
%{_libdir}/avkys
%{_libdir}/avkys/*.so
%{_kf5_qmldir}/AkQml
%{_kf5_qmldir}/AkQml/libAkQml.so
%{_kf5_qmldir}/AkQml/qmldir
%{_kf5_mandir}/man1/%{name}.1%{ext_man}
%{_kf5_iconsdir}/hicolor

%files devel
%{_libdir}/libavkys.so
%{_includedir}/avkys
%{_includedir}/avkys/*.h

%changelog
* Sat Mar 28 2020 Bogdano Arendartchuk <BArendartchuk@suse.com>
- require libqt5-qtquickcontrols and libqt5-qtquickcontrols2
* Tue Oct 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.7.1
  * Load virtual camera default frame from file instead of
    resources.
* Tue Oct  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.7.0
  * Removed unnecessary Bin and Probe plugins.
  * Added audio latency control.
  * Removed OSS and QtAudio submodules.
  * Fixed a bug that happened when changing the format, resolution
    or FPS of the camera (commit 41448aa).
  * Improved error messages for the virtual camera (issue #187).
  * Fixed segfaults.
* Tue Mar 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.6.1
  * AppImage now properly show the icon (issue #94).
  * Use correct subdir for manpage (issue #170, thanks Luigi
    Baldoni!).
- Dropped webcamoid-mandir.patch (merged upstream)
* Mon Mar 25 2019 Christophe Giboudeaux <christophe@krop.fr>
- Drop the qimageblitz dependency. Unused since 5.0.0.
- Drop the Frei0r dependency. Unused since 5.1.0.
- Fix the old description 'KDE' is the community, 'plasmoid' is no longer used.
- Ensure neutrality of description.
* Tue Mar  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.6.0
  * Now webcam settings are saved.
  * Enabled secondary plugins, and fixed segfaults and  memleaks
    in GStreamer.
  * Fixed segfaults and memory leaks in MacOS.
  * Fixed GIF playback in FFmpeg.
  * Build now support MSYS2.
  * Added static analysis with Codacy.
  * Fixed manpage install.
  * Install paths now follow Qt install paths structure.
- Added webcamoid-mandir.patch
* Tue Jan 22 2019 aloisio@gmx.com
- Update to version 8.5.0
  * UI ported to QtQuick Controls 2.
  * Reworked virtual camera for GNU/Linux, Mac and Windows.
  * Qt 5.9.0 as minimum requirement.
  * Faster build and smaller binaries.
  * Added build info.
  * Fixed crash and many other bugs in FreeBSD.
  * Added support for Microsoft Media Foundation capture.
  * Fixed shadow build.
  * Added support for FFmpeg 4.0.
  * Fixed bug when reading/setting webcam controls.
  * Added support for akvcam, default in-house virtual camera
    solution for GNU/Linux.
  * Fixed rendering problems in Mac.
  * Added support for FreeBSD in deploy scripts.
  * Fixed many bugs when recording audio and video.
  * Default recording video bitrate is now 1.5Mbps.
  * Fixed audio support in Windows.
  * Removed 'su' and 'sudo' as root method when installing the
    virtual camera in GNU/Linux.
  * Removed Syphon support for Mac.
  * Improved translations.
- Dropped webcamoid-8.1.0-ffmpeg4.patch (no longer necessary)
* Sun Jul  8 2018 aloisio@gmx.com
- Added webcamoid-8.1.0-ffmpeg4.patch to support ffmpeg4 and
  changed requirements accordingly
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Wed Dec 13 2017 aloisio@gmx.com
- Added frei0r-plugins-opencv as runtime requirement to account
  for (boo#1068792)
* Tue Oct 10 2017 aloisio@gmx.com
- Update to version 8.1.0
  * Improved startup time.
  * Deadlock when audio recording is enabled my be solved now.
    Audio recording enabled by default again.
  * Hopefully, fixed many segfaults in many platforms.
- Dropped webcamoid-fix_man.patch (merged upstream)
* Sat Jun 17 2017 aloisio@gmx.com
- Update to version 8.0.0
  * Added support for Mac and FreeBSD (virtual camera is not
    supported  * yet).
  * Added new masks to the FaceDetect plugin.
  * Now is possible to Switch between FFmpeg and GStreamer on
    runtime.
  * Added support for ALSA, OSS, JACK and QAudio.
  * Added support for libuvc.
  * Now is possible to select the desired input and output device,
    and  * configure playback and capture formats.
  * More translations updates.
  * Added options for configuring plugins search paths and
    blacklist  * in GUI.
  * Added options for configuring the desired frameworks and
    libraries.
  * Added formats and codecs config in recording options.
  * FFmpeg >= 3.1 required.
  * Added support for MSVC2013 and MSVC2015 build.
  * Added option for configure FPS in DesktopCapture plugin.
  * Added updates options.
  * AppImage support.
- Added webcamoid-fix_man.patch to address build problem on
  Tumbleweed
* Fri May 12 2017 aloisio@gmx.com
- Update to version 7.2.1
  * Added alternative root method (VirtualCamera). See ROOT_METHOD
    on project wiki.
  * C++11 support enabled by default.
  * Using new algorithm for Cartoon plugin.
  version 7.2.0:
  * Fixed problems when recording.
  * Added timer and flash when taking photos.
  * Better virtual camera management.
  * Added Virtual camera support for Windows.
  * Added GIF recording support (FFmpeg only).
  * Improved webcam format selection.
  * UI improvements.
  * Added play on start option.
  * Added C++11 support for Clang build.
- Renamed package to webcamoid
* Fri Apr 29 2016 aloisio@gmx.com
- Update to version 7.1.0
  * Reworked audio system.
  * Added support for compressed formats in webcams.
  * No more lags in the UI when capturing from webcam.
  * Added Windows installer.
  7.0.0:
  * Windows port finally working! EXPERIMENTAL!
  * Reworked recording options. More user friendly.
  * Removed unnecessary dependencies.
  * Many effects reworked and bugfixed.
  * Added GStreamer support, EXPERIMENTAL!
  * Fixed SEGFAULT when switching the effects.
  * Added virtual camera support (GNU/Linux only).
  * Added command line options for controlling plugins search.
  6.2.0:
  * Reworked Cartoonify plugin.
  * Some improvements in FaceDetect plugin.
  * Added Canny mode for Edge detection plugin.
  * Improved Blur and Denoise plugins.
  * Fixed QDataStream missing header.
  6.1.0:
  * Removed OpenCV as dependency (yes, again).
  * Fixed Denoise plugin SEGFAULT.
  * Translations updated.
  6.0.0:
  * New Qml UI, more user friendly.
  * Now, the effects can be customized.
  * A lot of bug fixes.
  5.1.0:
  * From now on, Webcamoid will be developed using Qt5.
  * Removed Frei0r from dependencies.
  * Added OpenCV as dependency (Face detection).
  * Removed plasmoid build since Qt5 plugins aren't compatible
    with Qt4/KDE4.
  * Now, Webcamoid can be compiled using MinGW.
  * Added webcam capture support through DirectShow.
  * There are still some patches needed to make it fully work
    in Windows.
  5.0.0:
  * Modified the effects preview for reducing resources usage.
  * Fixed stream flush on recording stop.
  * Enhanced webm video recording.
  5.0.0rc1:
  * Release Candidate version.
  * Ported to Qt5 (without the plasmoid).
  * Removed KDElibs as dependency, but still required for
    Qt4 build.
  * Removed QImageBlitz as dependency.
  * Added more effects.
  * Fixed video sync.
  * Initial port to Windows (help needed).
- Switched to Qt5
- Switched to ffmpeg 3.0
- Spec cleanup
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Mon Feb 10 2014 mailaender@opensuse.org
- Update to version 5.0.0b2
* Fri May  3 2013 fa0sck@gmail.com
- spec for openSUSE build changes:
  + Installpath all lowercase (patch)
  + Install under kde4_appsdir
  + generate help file
  + refresh translations
  + actually register plasmoid inside kde4_servicesdir
  + fix categories for desktop file
* Sun Oct 14 2012 mailaender@opensuse.org
- initial packaging
